@@ -18,7 +18,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -43,11 +42,10 @@
 #include "camel-exchange-journal.h"
 #include "camel-exchange-store.h"
 #include "camel-exchange-summary.h"
-
+#include "camel-exchange-utils.h"
 
 #define d(x)
 
-
 static void camel_exchange_journal_class_init (CamelExchangeJournalClass *klass);
 static void camel_exchange_journal_init (CamelExchangeJournal *journal, CamelExchangeJournalClass *klass);
 static void camel_exchange_journal_finalize (CamelObject *object);
@@ -57,10 +55,8 @@ static CamelDListNode *exchange_entry_load (CamelOfflineJournal *journal, FILE *
 static gint exchange_entry_write (CamelOfflineJournal *journal, CamelDListNode *entry, FILE *out);
 static gint exchange_entry_play (CamelOfflineJournal *journal, CamelDListNode *entry, CamelException *ex);
 
-
 static CamelOfflineJournalClass *parent_class = NULL;
 
-
 CamelType
 camel_exchange_journal_get_type (void)
 {
@@ -236,20 +232,14 @@ exchange_message_info_dup_to (CamelMessageInfoBase *dest, CamelMessageInfoBase *
 static gint
 exchange_entry_play_delete (CamelOfflineJournal *journal, CamelExchangeJournalEntry *entry, CamelException *ex)
 {
-	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
-
-	camel_stub_send_oneway (exchange_folder->stub,
-				CAMEL_STUB_CMD_SET_MESSAGE_FLAGS,
-				CAMEL_STUB_ARG_FOLDER,
-				((CamelFolder *)exchange_folder)->full_name,
-				CAMEL_STUB_ARG_STRING,
-				entry->uid,
-				CAMEL_STUB_ARG_UINT32,
-				entry->set,
-				CAMEL_STUB_ARG_UINT32,
-				entry->flags,
-				CAMEL_STUB_ARG_END);
+	CamelFolder *folder = (CamelFolder *) journal->folder;
 
+	camel_exchange_utils_set_message_flags (CAMEL_SERVICE (folder->parent_store),
+					folder->full_name,
+					entry->uid,
+					entry->set,
+					entry->flags,
+					ex);
 	return 0;
 }
 
@@ -290,7 +280,7 @@ exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEn
 		return -1;
 	}
 
-	real = camel_folder_summary_info_new_from_message (folder->summary, message);
+	real = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
 	camel_object_unref (message);
 
 	if (uid != NULL && real) {
@@ -356,7 +346,7 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 		camel_exception_init (&lex);
 		camel_folder_transfer_messages_to (src, uids, folder, &xuids, entry->delete_original, &lex);
 		if (!camel_exception_is_set (&lex)) {
-			real = camel_folder_summary_info_new_from_message (folder->summary, message);
+			real = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
 			camel_object_unref (message);
 			real->uid = camel_pstring_strdup ((gchar *)xuids->pdata[0]);
 			/* Transfer flags */
@@ -408,8 +398,6 @@ exchange_entry_play (CamelOfflineJournal *journal, CamelDListNode *entry, CamelE
 	}
 }
 
-
-
 CamelOfflineJournal *
 camel_exchange_journal_new (CamelExchangeFolder *folder, const gchar *filename)
 {
@@ -464,7 +452,7 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 
 	camel_object_unref (cache);
 
-	info = camel_folder_summary_info_new_from_message (folder->summary, message);
+	info = camel_folder_summary_info_new_from_message (folder->summary, message, NULL);
 	info->uid = camel_pstring_strdup (uid);
 
 	exchange_message_info_dup_to ((CamelMessageInfoBase *) info, (CamelMessageInfoBase *) mi);
@@ -563,7 +551,7 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 	type = find_real_source_for_message (source_folder, &real_source_folder,
 					     &real_uid, delete_original);
 
-	if(delete_original) {
+	if (delete_original) {
 		camel_exchange_folder_remove_message (source_folder, original_uid);
 	}
 
